@@ -11,7 +11,7 @@ class FileIO(ABC):
             storage_type = kw['storage_type'].lower()
         elif len(args) > 0:
             storage_type = args[0]
-        elif get_argument("hdfsUrl") is not None:
+        elif get_argument("webHdfsUrl") is not None:
             storage_type = "hdfs"
         else:
             storage_type = "filesystem"
